@@ -39,7 +39,7 @@ __copyright__ = 'Copyright 2014 Docker'
 __credits__ = []
 
 __license__ = 'Apache 2.0'
-__version__ = '2.0.1'
+__version__ = '2.0.2'
 __maintainer__ = 'Docker'
 __email__ = 'dev@docker.com'
 __status__ = 'Production'
@@ -47,6 +47,10 @@ __status__ = 'Production'
 __title__ = 'docker-registry-core'
 __build__ = 0x000000
 
+__url__ = 'https://github.com/docker/docker-registry'
+__description__ = 'Docker registry core package'
+__download__ = 'https://github.com/docker/docker-registry/archive/master.zip'
+
 try:
     NullHandler = logging.NullHandler
 except AttributeError:
